photoshop_python_api documentation
==================================

The API for using COM (Component Object Model) objects interfaces of Photoshop.

.. toctree::
   :maxdepth: 2

   installation
   usage
   src/modules
   history
